@@ -115,9 +115,15 @@ class ChatSession:
     def _select_profile_and_role(self, args, role):
         profile = getattr(args, "profile", None) if args is not None else None
         role_arg = getattr(args, "role", None) if args is not None else None
+        python_profile = getattr(args, "python", False) if args is not None else False
         profile_system_prompt = None
         no_tools_mode = False
-        if profile is None and role_arg is None:
+
+        # Handle --python flag
+        if python_profile and profile is None and role_arg is None:
+            profile = "Developer with Python Tools"
+
+        if profile is None and role_arg is None and not python_profile:
             try:
                 from janito.cli.chat_mode.session_profile_select import select_profile
 
@@ -277,6 +283,59 @@ class ChatSession:
                 else None
             )
             start_time = time.time()
+
+            # Print rule line with model info before processing prompt
+            model_name = (
+                self.agent.get_model_name()
+                if hasattr(self.agent, "get_model_name")
+                else "Unknown"
+            )
+            provider_name = (
+                self.agent.get_provider_name()
+                if hasattr(self.agent, "get_provider_name")
+                else "Unknown"
+            )
+
+            backend_hostname = "Unknown"
+            candidates = []
+            drv = getattr(self.agent, "driver", None)
+            if drv is not None:
+                cfg = getattr(drv, "config", None)
+                if cfg is not None:
+                    b = getattr(cfg, "base_url", None)
+                    if b:
+                        candidates.append(b)
+                direct_base = getattr(drv, "base_url", None)
+                if direct_base:
+                    candidates.append(direct_base)
+            cfg2 = getattr(self.agent, "config", None)
+            if cfg2 is not None:
+                b2 = getattr(cfg2, "base_url", None)
+                if b2:
+                    candidates.append(b2)
+            top_base = getattr(self.agent, "base_url", None)
+            if top_base:
+                candidates.append(top_base)
+            from urllib.parse import urlparse
+            for candidate in candidates:
+                try:
+                    if not candidate:
+                        continue
+                    parsed = urlparse(str(candidate))
+                    host = parsed.netloc or parsed.path
+                    if host:
+                        backend_hostname = host
+                        break
+                except Exception:
+                    backend_hostname = str(candidate)
+                    break
+
+            self.console.print(
+                Rule(
+                    f"[bold blue]Model: {model_name} ({provider_name}) | Backend: {backend_hostname}[/bold blue]"
+                )
+            )
+
             self._prompt_handler.run_prompt(cmd_input)
             end_time = time.time()
             elapsed = end_time - start_time
