@@ -8,6 +8,8 @@ from janito.cli.cli_commands.list_tools import handle_list_tools
 from janito.cli.cli_commands.show_config import handle_show_config
 from janito.cli.cli_commands.list_config import handle_list_config
 from janito.cli.cli_commands.list_drivers import handle_list_drivers
+from janito.regions.cli import handle_region_info
+from janito.cli.cli_commands.list_providers_region import handle_list_providers_region
 from functools import partial
 from janito.provider_registry import ProviderRegistry
 
@@ -19,6 +21,8 @@ GETTER_KEYS = [
     "list_tools",
     "list_config",
     "list_drivers",
+    "region_info",
+    "list_providers_region",
 ]
 
 
@@ -45,9 +49,9 @@ def handle_getter(args, config_mgr=None):
         "show_config": partial(handle_show_config, args),
         "list_config": partial(handle_list_config, args),
         "list_drivers": partial(handle_list_drivers, args),
+        "region_info": partial(handle_region_info, args),
+        "list_providers_region": partial(handle_list_providers_region, args),
     }
     for arg in GETTER_KEYS:
         if getattr(args, arg, False) and arg in GETTER_DISPATCH:
-            GETTER_DISPATCH[arg]()
-            import sys
-            sys.exit(0)
+            return GETTER_DISPATCH[arg]()
