@@ -36,6 +36,13 @@ definition = [
             "default": None,
         },
     ),
+    (
+        ["--python"],
+        {
+            "action": "store_true",
+            "help": "Start with the Python developer profile (equivalent to --profile 'Developer with Python Tools')",
+        },
+    ),
     (
         ["--role"],
         {
@@ -117,9 +124,30 @@ definition = [
         ["--list-providers"],
         {"action": "store_true", "help": "List supported LLM providers"},
     ),
+    (
+        ["--ping"],
+        {"action": "store_true", "help": "Ping/test connectivity for all providers (use with --list-providers)"},
+    ),
     (
         ["--list-drivers"],
-        {"action": "store_true", "help": "List available LLM drivers and their dependencies"},
+        {
+            "action": "store_true",
+            "help": "List available LLM drivers and their dependencies",
+        },
+    ),
+    (
+        ["--region-info"],
+        {
+            "action": "store_true",
+            "help": "Show current region information and location",
+        },
+    ),
+    (
+        ["--list-providers-region"],
+        {
+            "action": "store_true",
+            "help": "List all providers with their regional API information",
+        },
     ),
     (
         ["-l", "--list-models"],
@@ -192,6 +220,7 @@ MODIFIER_KEYS = [
     "model",
     "role",
     "profile",
+    "python",
     "system",
     "temperature",
     "verbose",
@@ -211,6 +240,21 @@ GETTER_KEYS = [
     "list_tools",
     "list_config",
     "list_drivers",
+    "region_info",
+    "list_providers_region",
+    "ping",
+]
+GETTER_KEYS = [
+    "show_config",
+    "list_providers",
+    "list_profiles",
+    "list_models",
+    "list_tools",
+    "list_config",
+    "list_drivers",
+    "region_info",
+    "list_providers_region",
+    "ping",
 ]
 
 
@@ -327,7 +371,15 @@ class JanitoCLI:
             if self._run_set_mode():
                 return
         # Special handling: provider is not required for list_providers, list_tools, show_config, list_drivers
-        if run_mode == RunMode.GET:
+        if run_mode == RunMode.GET and (
+            self.args.list_providers
+            or self.args.list_tools
+            or self.args.list_profiles
+            or self.args.show_config
+            or self.args.list_config
+            or self.args.list_drivers
+            or self.args.ping
+        ):
             self._maybe_print_verbose_provider_model()
             handle_getter(self.args)
             return
@@ -363,7 +415,8 @@ class JanitoCLI:
                 agent_role,
                 verbose_tools=self.args.verbose_tools,
             )
-
+        elif run_mode == RunMode.GET:
+            handle_getter(self.args)
 
     def _run_set_mode(self):
         if handle_api_key_set(self.args):
