@@ -7,3 +7,5 @@ import janito.providers.deepseek.provider
 import janito.providers.moonshotai.provider
 import janito.providers.alibaba.provider
 import janito.providers.zai.provider
+import janito.providers.cerebras.provider
+import janito.providers.mistral.provider
